TapeElement

Enum TapeElement 

pub enum TapeElement {
Show 13 variants StartObject(u32), EndObject(u32), StartList(u32), EndList(u32), String(u32), Number(u32), I64(i32), I32(i32), F64(u32), F32(u32), True, False, Null,
}
We decode JSON to a flattened tape representation, allowing for efficient traversal of the JSON data

This approach is inspired by simdjson

Uses u32 for offsets to ensure TapeElement is 64-bits. A future iteration may increase this to a custom u56 type.

Variants



StartObject(u32)

The start of an object, i.e. {

Contains the offset of the corresponding Self::EndObject



EndObject(u32)

The end of an object, i.e. }

Contains the offset of the corresponding Self::StartObject



StartList(u32)

The start of a list , i.e. [

Contains the offset of the corresponding Self::EndList



EndList(u32)

The end of a list , i.e. ]

Contains the offset of the corresponding Self::StartList



String(u32)

A string value

Contains the offset into the Tape string data



Number(u32)

A numeric value

Contains the offset into the Tape string data



I64(i32)

The high bits of a i64

Followed by Self::I32 containing the low bits



I32(i32)

A 32-bit signed integer

May be preceded by Self::I64 containing high bits



F64(u32)

The high bits of a 64-bit float

Followed by Self::F32 containing the low bits



F32(u32)

A 32-bit float or the low-bits of a 64-bit float if preceded by Self::F64



True

A true literal



False

A false literal



Null

A null literal